==> owncloud-4.0.4.tgz: owncloud/apps/calendar/l10n/he.php <==
<?php $TRANSLATIONS = array(
"No calendars found." => "לא נמצאו לוחות שנה.",
"No events found." => "לא נמצאו אירועים.",
"Wrong calendar" => "לוח שנה לא נכון",
"New Timezone:" => "אזור זמן חדש:",
"Timezone changed" => "אזור זמן השתנה",
"Invalid request" => "בקשה לא חוקית",
"Calendar" => "ח שנה",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "d MMM [ yyyy]{ '&#8212;'d[ MMM] yyyy}",
"Birthday" => "יום הולדת",
"Business" => "עסקים",
"Call" => "שיחה",
"Clients" => "לקוחות",
"Deliverer" => "משלוח",
"Holidays" => "חגים",
"Ideas" => "רעיונות",
"Journey" => "מסע",
"Jubilee" => "יובל",
"Meeting" => "פגישה",
"Other" => "אחר",
"Personal" => "אישי",
"Projects" => "פרוייקטים",
"Questions" => "שאלות",
"Work" => "עבודה",
"unnamed" => "ללא שם",
"Does not repeat" => "ללא חזרה",
"Daily" => "יומי",
"Weekly" => "שבועי",
"Every Weekday" => "כל יום עבודה",
"Bi-Weekly" => "דו שבועי",
"Monthly" => "חודשי",
"Yearly" => "שנתי",
"never" => "לעולם לא",
"by occurrences" => "לפי מופעים",
"by date" => "לפי תאריך",
"by monthday" => "לפי היום בחודש",
"by weekday" => "לפי היום בשבוע",
"Monday" => "יום שני",
"Tuesday" => "יום שלישי",
"Wednesday" => "יום רביעי",
"Thursday" => "יום חמישי",
"Friday" => "יום שישי",
"Saturday" => "שבת",
"Sunday" => "יום ראשון",
"events week of month" => "שבוע בחודש לציון הפעילות",
"first" => "ראשון",
"second" => "שני",
"third" => "שלישי",
"fourth" => "רביעי",
"fifth" => "חמישי",
"last" => "אחרון",
"January" => "ינואר",
"February" => "פברואר",
"March" => "מרץ",
"April" => "אפריל",
"May" => "מאי",
"June" => "יוני",
"July" => "יולי",
"August" => "אוגוסט",
"September" => "ספטמבר",
"October" => "אוקטובר",
"November" => "נובמבר",
"December" => "דצמבר",
"by events date" => "לפי תאריכי האירועים",
"by yearday(s)" => "לפי ימים בשנה",
"by weeknumber(s)" => "לפי מספרי השבועות",
"by day and month" => "לפי יום וחודש",
"Date" => "תאריך",
"Cal." => "לוח שנה",
"All day" => "היום",
"New Calendar" => "לוח שנה חדש",
"Missing fields" => "שדות חסרים",
"Title" => "כותרת",
"From Date" => "מתאריך",
"From Time" => "משעה",
"To Date" => "עד תאריך",
"To Time" => "עד שעה",
"The event ends before it starts" => "האירוע מסתיים עוד לפני שהתחיל",
"There was a database fail" => "אירע כשל במסד הנתונים",
"Week" => "שבוע",
"Month" => "חודש",
"List" => "רשימה",
"Today" => "היום",
"Calendars" => "לוחות שנה",
"There was a fail, while parsing the file." => "אירעה שגיאה בעת פענוח הקובץ.",
"Choose active calendars" => "בחר לוחות שנה פעילים",
"Your calendars" => "לוחות השנה שלך",
"CalDav Link" => "קישור CalDav",
"Shared calendars" => "לוחות שנה מושתפים",
"No shared calendars" => "אין לוחות שנה משותפים",
"Share Calendar" => "שיתוף לוח שנה",
"Download" => "הורדה",
"Edit" => "עריכה",
"Delete" => "מחיקה",
"shared with you by" => "שותף אתך על ידי",
"New calendar" => "לוח שנה חדש",
"Edit calendar" => "עריכת לוח שנה",
"Displayname" => "שם תצוגה",
"Active" => "פעיל",
"Calendar color" => "צבע לוח שנה",
"Save" => "שמירה",
"Submit" => "שליחה",
"Cancel" => "ביטול",
"Edit an event" => "עריכת אירוע",
"Export" => "יצוא",
"Eventinfo" => "פרטי האירוע",
"Repeating" => "חוזר",
"Alarm" => "תזכורת",
"Attendees" => "משתתפים",
"Share" => "שיתוף",
"Title of the Event" => "כותרת האירוע",
"Category" => "קטגוריה",
"Separate categories with commas" => "הפרדת קטגוריות בפסיק",
"Edit categories" => "עריכת קטגוריות",
"All Day Event" => "אירוע של כל היום",
"From" => "מאת",
"To" => "עבור",
"Advanced options" => "אפשרויות מתקדמות",
"Location" => "מיקום",
"Location of the Event" => "מיקום האירוע",
"Description" => "תיאור",
"Description of the Event" => "תיאור האירוע",
"Repeat" => "חזרה",
"Advanced" => "מתקדם",
"Select weekdays" => "יש לבחור ימים בשבוע",
"Select days" => "יש לבחור בימים",
"and the events day of year." => "ויום האירוע בשנה.",
"and the events day of month." => "ויום האירוע בחודש.",
"Select months" => "יש לבחור בחודשים",
"Select weeks" => "יש לבחור בשבועות",
"and the events week of year." => "ומספור השבוע הפעיל בשנה.",
"Interval" => "משך",
"End" => "סיום",
"occurrences" => "מופעים",
"Import a calendar file" => "יבוא קובץ לוח שנה",
"Please choose the calendar" => "נא לבחור את לוח השנה",
"create a new calendar" => "יצירת לוח שנה חדש",
"Name of new calendar" => "שם לוח השנה החדש",
"Import" => "יבוא",
"Importing calendar" => "היומן מייובא",
"Calendar imported successfully" => "היומן ייובא בהצלחה",
"Close Dialog" => "סגירת הדו־שיח",
"Create a new event" => "יצירת אירוע חדש",
"View an event" => "צפייה באירוע",
"No categories selected" => "לא נבחרו קטגוריות",
"Select category" => "בחר קטגוריה",
"of" => "מתוך",
"at" => "בשנה",
"Timezone" => "אזור זמן",
"Check always for changes of the timezone" => "יש לבדוק תמיד אם יש הבדלים באזורי הזמן",
"Timeformat" => "מבנה התאריך",
"24h" => "24 שעות",
"12h" => "12 שעות",
"First day of the week" => "היום הראשון בשבוע",
"Calendar CalDAV syncing address:" => "כתובת הסנכרון ללוח שנה מסוג CalDAV:",
"Users" => "משתמשים",
"select users" => "נא לבחור במשתמשים",
"Editable" => "ניתן לעריכה",
"Groups" => "קבוצות",
"select groups" => "בחירת קבוצות",
"make public" => "הפיכה לציבורי"
);

==> owncloud-4.5.7.tgz: owncloud/apps/calendar/l10n/he.php <==
<?php $TRANSLATIONS = array(
"No calendars found." => "לא נמצאו לוחות שנה.",
"No events found." => "לא נמצאו אירועים.",
"Wrong calendar" => "לוח שנה לא נכון",
"Import failed" => "כשלון ביבוא",
"New Timezone:" => "אזור זמן חדש:",
"Timezone changed" => "אזור זמן השתנה",
"Invalid request" => "בקשה לא חוקית",
"Calendar" => "לוח שנה",
"user" => "משתמש",
"group" => "קבוצה",
"Editable" => "ניתן לעריכה",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "d MMM [ yyyy]{ '&#8212;'d[ MMM] yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Birthday" => "יום הולדת",
"Business" => "עסקים",
"Call" => "שיחה",
"Clients" => "לקוחות",
"Deliverer" => "משלוח",
"Holidays" => "חגים",
"Ideas" => "רעיונות",
"Journey" => "מסע",
"Jubilee" => "יובל",
"Meeting" => "פגישה",
"Other" => "אחר",
"Personal" => "אישי",
"Projects" => "פרוייקטים",
"Questions" => "שאלות",
"Work" => "עבודה",
"by" => "מאת",
"unnamed" => "ללא שם",
"New Calendar" => "לוח שנה חדש",
"Does not repeat" => "ללא חזרה",
"Daily" => "יומי",
"Weekly" => "שבועי",
"Every Weekday" => "כל יום עבודה",
"Bi-Weekly" => "דו שבועי",
"Monthly" => "חודשי",
"Yearly" => "שנתי",
"never" => "לעולם לא",
"by occurrences" => "לפי מופעים",
"by date" => "לפי תאריך",
"by monthday" => "לפי היום בחודש",
"by weekday" => "לפי היום בשבוע",
"Monday" => "יום שני",
"Tuesday" => "יום שלישי",
"Wednesday" => "יום רביעי",
"Thursday" => "יום חמישי",
"Friday" => "יום שישי",
"Saturday" => "שבת",
"Sunday" => "יום ראשון",
"events week of month" => "שבוע בחודש לציון הפעילות",
"first" => "ראשון",
"second" => "שני",
"third" => "שלישי",
"fourth" => "רביעי",
"fifth" => "חמישי",
"last" => "אחרון",
"January" => "ינואר",
"February" => "פברואר",
"March" => "מרץ",
"April" => "אפריל",
"May" => "מאי",
"June" => "יוני",
"July" => "יולי",
"August" => "אוגוסט",
"September" => "ספטמבר",
"October" => "אוקטובר",
"November" => "נובמבר",
"December" => "דצמבר",
"by events date" => "לפי תאריכי האירועים",
"by yearday(s)" => "לפי ימים בשנה",
"by weeknumber(s)" => "לפי מספרי השבועות",
"by day and month" => "לפי יום וחודש",
"Date" => "תאריך",
"Cal." => "לוח שנה",
"Sun." => "א",
"Mon." => "ב",
"Tue." => "ג",
"Wed." => "ד",
"Thu." => "ה",
"Fri." => "ו",
"Sat." => "ש",
"Jan." => "ינו׳",
"Feb." => "פבר׳",
"Mar." => "מרץ",
"Apr." => "אפר׳",
"May." => "מאי",
"Jun." => "יונ׳",
"Jul." => "יול׳",
"Aug." => "אוג׳",
"Sep." => "ספט׳",
"Oct." => "אוק׳",
"Nov." => "נוב׳",
"Dec." => "דצמ׳",
"All day" => "היום",
"Missing fields" => "שדות חסרים",
"Title" => "כותרת",
"From Date" => "מתאריך",
"From Time" => "משעה",
"To Date" => "עד תאריך",
"To Time" => "עד שעה",
"The event ends before it starts" => "האירוע מסתיים עוד לפני שהתחיל",
"There was a database fail" => "אירע כשל במסד הנתונים",
"Week" => "שבוע",
"Month" => "חודש",
"List" => "רשימה",
"Today" => "היום",
"Settings" => "הגדרות",
"Your calendars" => "לוחות השנה שלך",
"CalDav Link" => "קישור CalDav",
"Share Calendar" => "שיתוף לוח שנה",
"Download" => "הורדה",
"Edit" => "עריכה",
"Delete" => "מחיקה",
"shared with you by" => "שותף אתך על ידי",
"New calendar" => "לוח שנה חדש",
"Edit calendar" => "עריכת לוח שנה",
"Displayname" => "שם תצוגה",
"Active" => "פעיל",
"Calendar color" => "צבע לוח שנה",
"Save" => "שמירה",
"Submit" => "שליחה",
"Cancel" => "ביטול",
"Edit an event" => "עריכת אירוע",
"Export" => "יצוא",
"Eventinfo" => "פרטי האירוע",
"Repeating" => "חוזר",
"Alarm" => "תזכורת",
"Attendees" => "משתתפים",
"Share" => "שיתוף",
"Title of the Event" => "כותרת האירוע",
"Category" => "קטגוריה",
"Separate categories with commas" => "הפרדת קטגוריות בפסיק",
"Edit categories" => "עריכת קטגוריות",
"All Day Event" => "אירוע של כל היום",
"From" => "מאת",
"To" => "עבור",
"Advanced options" => "אפשרויות מתקדמות",
"Location" => "מיקום",
"Location of the Event" => "מיקום האירוע",
"Description" => "תיאור",
"Description of the Event" => "תיאור האירוע",
"Repeat" => "חזרה",
"Advanced" => "מתקדם",
"Select weekdays" => "יש לבחור ימים בשבוע",
"Select days" => "יש לבחור בימים",
"and the events day of year." => "ויום האירוע בשנה.",
"and the events day of month." => "ויום האירוע בחודש.",
"Select months" => "יש לבחור בחודשים",
"Select weeks" => "יש לבחור בשבועות",
"and the events week of year." => "ומספור השבוע הפעיל בשנה.",
"Interval" => "משך",
"End" => "סיום",
"occurrences" => "מופעים",
"create a new calendar" => "יצירת לוח שנה חדש",
"Import a calendar file" => "יבוא קובץ לוח שנה",
"Please choose a calendar" => "נא לבחור לוח שנה",
"Name of new calendar" => "שם לוח השנה החדש",
"Import" => "יבוא",
"Close Dialog" => "סגירת הדו־שיח",
"Create a new event" => "יצירת אירוע חדש",
"View an event" => "צפייה באירוע",
"No categories selected" => "לא נבחרו קטגוריות",
"of" => "מתוך",
"at" => "בשנה",
"General" => "כללי",
"Timezone" => "אזור זמן",
"Update timezone automatically" => "עדכון אזור זמן אוטומטי",
"Time format" => "תבנית זמן",
"24h" => "24 שעות",
"12h" => "12 שעות",
"Start week on" => "שבוע מתחיל ביום",
"Cache" => "מטמון",
"URLs" => "כתובות",
"more info" => "מידע נוסף",
"iOS/OS X" => "iOS/OS X"
);
